# Migrate from v1.1 to v1.2

## Asset Store - Minio

Minio's `content` bucket is removed in this release. We stopped using it in Kyma 0.9 and provided automated scripts to migrate registered applications to new buckets.

As a result, this information is important for users that uploaded files to the `content` bucket manually.

Before you upgrade to 1.2, make sure to backup all data stored in the `content` bucket. Run this command to copy all the assets from the `content` bucket to the `minio-backup` catalog in the user's Home directory:

```
kubectl -n kyma-system cp $(kubectl -n kyma-system get pod -l app=minio -o jsonpath="{.items[0].metadata.name}"):/export/content $HOME/minio-backup
```

## Application Connector

In the 1.2 release, the Application Connector is no longer exposed by the Nginx Ingress Controller and uses the Istio Ingress Gateway instead.

After upgrading Kyma to the 1.2 release, the `gateway.{CLUSTER_DOMAIN}` subdomain should point to the IP of the Istio Ingress Gateway. Therefore the DNS mapping for this subdomain must be deleted in your Cloud Provider's service.
There is no need to create a new DNS mapping as the wildcard domain will be used, which by default points to the Istio Ingress Gateway.

## Event Bus

The 1.2 release updates the Knative eventing version to 0.5 from 0.4. This brings in considerable changes to the Knative eventing CRDs which cannot be automatically done in Kyma update. To accommodate them, the following post update steps needs to be followed.

1. Delete all the existing Knative eventing subscription custom resources. They will be recreated after all  the steps are completed.

    ```bash
    kubectl delete subscriptions.eventing.knative.dev --all -n kyma-system
    ```
 
2. Delete all the existing Knative eventing channels custom resources. They will be recreated after all  the steps are completed.
    
    ```bash
    kubectl delete channels.eventing.knative.dev --all -n kyma-system
    ```

3. Apply all the Knative eventing CRDs that have delta in 0.5 release.

    ```bash
    kubectl apply -f https://raw.githubusercontent.com/kyma-project/kyma/1.2.0/components/event-bus/cmd/event-bus-crd-update-job/crds.yaml
    ```

4. Restart the subscription controller pod. This will reconcile all the Kyma subscriptions and the create all the Knative channels and subscriptions.

    ```bash
    kubectl delete pod -l app=event-bus-subscription-controller-knative -n kyma-system
    ```